# Experience-Platform-Python-SDK

#### This Python SDK is designed to facilitate access to the Adobe Experience Platform Rest APIs and the associated tools.

#### In order to use this SDK you will first need to have an account with the Adobe Experience Platform along with the necessary authentication information.

#### See the [Adobe Experience Platform API Documentation](https://www.adobe.io/apis/experienceplatform/home/api-reference.html) for more information.

---

## Getting Started

To begin first install the required dependencies using "pip install -r requirements.txt" in the terminal